/**********************************************************************
Copyright (c) 2010 Todd Nine. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors :
    ...
 ***********************************************************************/
package com.spidertracks.datanucleus.basic.model;

import java.io.Serializable;
import java.util.Date;
import java.util.StringTokenizer;

/**
 * @author Todd Nine
 * 
 */
public class UnitDataNoConverterKey implements Serializable {

	/**
		 * 
		 */
	private static final long serialVersionUID = 1507634768434382394L;
	public Date createdDate;
	public String unitId;

	public UnitDataNoConverterKey() {
	}

	public UnitDataNoConverterKey(Date createdDate, String unitId) {
		this.createdDate = createdDate;
		this.unitId = unitId;
	}

	/**
	 * Constructor accepting same input as generated by toString().
	 */
	public UnitDataNoConverterKey(String value) {
		StringTokenizer token = new StringTokenizer(value, "::");

		this.unitId = token.nextToken();
		this.createdDate = new Date(Long.parseLong(token.nextToken()));

	}

	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (!(obj instanceof UnitDataNoConverterKey)) {
			return false;
		}
		UnitDataNoConverterKey c = (UnitDataNoConverterKey) obj;

		return unitId.equals(c.unitId) && createdDate.equals(c.createdDate);
	}

	@Override
	public int hashCode() {
		return this.unitId.hashCode() ^ this.createdDate.hashCode();
	}

	public String toString() {
		// Give output expected by String constructor
		return this.unitId + "::" + this.createdDate.getTime();
	}

}
